<?php

/**
 * Request to backend
 * @param $endpoint
 * @param $data
 * @param $key
 * @param $license_id
 * @param $domain
 * @param $service
 * @return array|mixed
 */
function skyposter_request($endpoint, $data, $key, $license_id, $domain, $service)
{

   $TM_SERVER = "https://my.skyposter.pro/";

   // Attach to request data about license
   $data['domain'] = $domain;
   $data['hash'] = $key;
   $data['service'] = $service;
   if(!isset($data['license'])) $data['license'] = $license_id;

   // Random ID for every new task
   if(!isset($data['task'])) $data['task'] = skyposter_generateUniqueID();

   // REQUEST
   $endpoint = $TM_SERVER . $endpoint;
   $args = [
      'body'        => wp_json_encode($data),
      'timeout'     => 360,
      'httpversion' => '1.1',
      'blocking'    => true,
      'headers'     => [
         'Content-Type' => 'application/json'
      ],
   ];

   // Get response
   $response = wp_remote_post($endpoint, $args);

   // log request for debug or technical support
   // skyposter_log($data, $response);

   if (is_wp_error($response)) {
      return [
         'status' => 'error',
         'message' => $response->get_error_message()
      ];
   } else {
      $result = json_decode(wp_remote_retrieve_body($response), true);
      return $result;
   }

}

/**
 * Register new installation of plugin in backend
 * @param $domain
 * @param $serviceID
 * @param $license
 * @return array|mixed
 */
function skyposter_register($domain, $serviceID, $license)
{
   $key = skyposter_generateUniqueID();
   return skyposter_request('site/task', [
      'task' => skyposter_generateUniqueID(),
      'type' => 'REGISTER',
   ], $key, $license, $domain, $serviceID);
}

/**
 * Unique ID generator
 * @return string
 */
function skyposter_generateUniqueID()
{
   return md5(microtime().$_SERVER['HTTP_USER_AGENT']).md5(microtime().$_SERVER['REQUEST_TIME']);
}

