<?php

$unique_id = get_option('skyposter_plugin_unique_id');

/**
 * Select language or articles automatically
 * @param $locale
 * @return string
 */
function get_language_name($locale)
{
   $languages = array(
      'en_US' => 'English',
      'en_GB' => 'English',
      'zh_CN' => '中文 (简体)',
      'zh_TW' => '中文 (繁體)',
      'es_ES' => 'Español',
      'es_MX' => 'Español',
      'hi_IN' => 'हिन्दी',
      'ar_SA' => 'العربية',
      'bn_IN' => 'বাংলা',
      'pt_PT' => 'Português',
      'pt_BR' => 'Português',
      'ru_RU' => 'Русский',
      'ja_JP' => '日本語',
      'de_DE' => 'Deutsch',
      'ko_KR' => '한국어',
      'fr_FR' => 'Français',
      'fr_CA' => 'Français',
      'vi_VN' => 'Tiếng Việt',
      'tr_TR' => 'Türkçe',
      'it_IT' => 'Italiano',
      'pl_PL' => 'Polski',
      'uk_UA' => 'Українська',
      'nl_NL' => 'Nederlands',
      'el_GR' => 'Ελληνικά',
      'sv_SE' => 'Svenska',
      'hu_HU' => 'Magyar',
      'fi_FI' => 'Suomi',
      'da_DK' => 'Dansk',
      'he_IL' => 'עברית',
      'th_TH' => 'ไทย',
   );

   if (isset($languages[$locale])) {
      return $languages[$locale];
   } elseif (extension_loaded('intl')) {
      return Locale::getDisplayLanguage($locale, "en");
   } else {
      return $locale;
   }

}

$language_name = get_language_name(get_locale());


?>

<div class="wp-style-flex-container">


    <div class="header">
        <div class="logo"><h1>SkyPoster - AI content via GPT with SEO optimization</h1></div>
        <div class="tab">
            <button class="tablinks button button-small" id="TM_TabGenerator"
                    onclick="skyposter_changeTab(event, 'Generator')"><?php esc_html_e("Generator", "skyposter") ?></button>
            <button class="tablinks button button-small" id="TM_TabSettings"
                    onclick="skyposter_changeTab(event, 'Settings')"><?php esc_html_e("Settings", "skyposter") ?></button>
        </div>
    </div>

    <div style="margin-top: 5px">
       <span style="border-radius: 3px; padding: 3px 8px; background: #4dc54a; color: white; "><?php esc_html_e("My credits", "skyposter") ?>:
            <span skyposter_bananas=""></span>
       </span>
        <a style="margin-left: 5px; text-decoration: auto; border-radius: 3px; padding: 3px 8px; background: #4dc54a; color: white;"
           href="https://my.skyposter.pro/buy/<?php echo esc_html($unique_id) ?>" target="_blank"><?php esc_html_e("Buy credits", "skyposter") ?></a>
       <?php if (defined('WPSEO_VERSION')): ?>
           <span style="border-radius: 3px; padding: 2px 4px; background: rgba(76,169,76,0.51); color: white; margin-left: 15px;">
                <?php esc_html_e('YOAST SEO connected', 'skyposter') ?>
            </span>
       <?php endif; ?>
       <?php if (function_exists('aioseo')): ?>
           <span style="border-radius: 3px; padding: 2px 4px; background: rgba(76,169,76,0.51); color: white; margin-left: 15px;">
                <?php esc_html_e('All in One SEO connected', 'skyposter') ?>
            </span>
       <?php endif; ?>
    </div>


    <div id="Generator" class="tabcontent">
        <div class="section">
            <div class style="margin: 20px 0">
                <div class style="display:flex;align-items: center;">
                    <div class="number"
                         style="width: 28px;height: 28px;font-size: 20px;line-height: initial;text-align: center;border: 1px solid #000;border-radius: 50%;line-height: 1.4;margin-right: 10px;">
                        1
                    </div>
                    <h2><?php esc_html_e("Topic of the posts", "skyposter") ?></h2>
                </div>
                <p style="margin-top: -5px;"><?php esc_html_e("To generate posts you need to set key phrases. The key phrase describes what the text will be about", "skyposter") ?>
                <br/>
                    <?php esc_html_e("One key phrase - one post. You can use services from Google and Yandex to select phrases:", "skyposter") ?>
                </p>

                <div class="notice notice-info is-dismissible" style="margin: 5px 0px 12px;">
                    <p><?php esc_html_e("Key phrases are search queries that users write to search engines. All search phrases form a semantic core", "skyposter") ?></p>
                </div>
                <div>
                    <a target="_blank" style="margin-right:15px"
                       href="https://wordstat-2.yandex.ru/?region=all&view=table&words=<?php echo urlencode(get_bloginfo('name')) ?>"><?php esc_html_e("Yandex Wordstat", "skyposter") ?></a>
                    <a target="_blank"
                       href="https://ads.google.com/aw/keywordplanner/home"><?php esc_html_e("Google Keyword planner", "skyposter") ?></a>
                </div>
                <br>

            </div>
            <div class="flex-container theme">
                <div style="" class="keywords_block">
                    <h3><?php esc_html_e("Write the key phrases manually", "skyposter") ?></h3>
                    <p><?php esc_html_e("List key phrases, one phrase on each new line", "skyposter") ?></p>
                    <p><?php esc_html_e("Supported formats: 1) keyword 2) \"keyword; article description and style; title; h1; meta description\" - you can specify any number of parameters in order", "skyposter") ?></p>
                    <div id="skyposter_keylist_wrap">
                    <textarea rows="7" id="skyposter_keyWords"
                              style="width: 100%; background-color: transparent; font-size: 12px"
                              placeholder="<?php esc_html_e("Keyword 1\nKeyword 2\nKeyword 3; article prompt\nKeyword 4; article prompt; title; h1; meta-desc", "skyposter") ?>"
                    ></textarea>
                        <div id="skyposter_placeholderDiv"></div>
                    </div>
                </div>
                <div style="margin-left: 0px;" class="keywords_block">
                    <h3><?php esc_html_e("Generate key phrases", "skyposter") ?></h3>
                    <p><?php esc_html_e("Specify the topic and we will come up with key phrases on the basis of which the posts will be created", "skyposter") ?> </p>
                    <input type="text" id="newKeyword" placeholder="<?php esc_html_e("Key phrase topics", "skyposter") ?>"
                           style="width: 70%">

                    <p>
                    <div><?php esc_html_e("How many keyword phrases do you need?", "skyposter") ?></div>
                    <div><input type="number" value="2" id="totalArticles"
                                placeholder="<?php esc_html_e("Total number of key phrases needed", "skyposter") ?>">
                    </div>
                    </p>

                    <button onclick="generateKeyword()" class="button-primary"
                            style="margin: 1em 0;"><?php esc_html_e("Generate keywords", "skyposter") ?></button>
                    <div id="KeywordsError"></div>
                </div>

                <div class="keywords_block" style="margin-left:0px">
                    <h3><?php esc_html_e("Load from file", "skyposter") ?></h3>
                    <p><?php esc_html_e("Upload a file that lists your keyword phrases", "skyposter") ?></p>
                    <input type="file" onchange="" id="loadFile"/>
                    <button class="button-primary"><label for="loadFile">
                          <?php esc_html_e("Select a file", "skyposter") ?>
                            <p class="file-name"></p>
                        </label></button>
                </div>
            </div>
        </div>
        <br>

        <div class="section">
            <h2>
                <div class style="display:flex;align-items: center;">
                    <div class="number"
                         style="width: 28px;height: 28px;font-size: 20px;line-height: initial;text-align: center;border: 1px solid #000;border-radius: 50%;line-height: 1.4;margin-right: 10px;">
                        2
                    </div>
                    <h2><?php esc_html_e("Settings", "skyposter") ?></h2></div>
            </h2>

            <div style="" class="settings">

                <div class="" style="display:flex;flex-direction:column;margin-right:30px">
                    <div><?php esc_html_e("Select model", "skyposter") ?></div>
                    <select skyposter_models>
                        <option value="gpt-3.5-turbo">ChatGPT 3.5 [1 <?php esc_html_e("credit", "skyposter") ?>]</option>
                        <option value="gpt-4-turbo-preview" selected>ChatGPT 4 [2 <?php esc_html_e("credits", "skyposter") ?>]
                        </option>
                        <option value="gpt-4o" selected>ChatGPT 4o [2 <?php esc_html_e("credits", "skyposter") ?>]</option>
                    </select>
                    <!-- disabled -->
                    <label style="display:none"><input type="checkbox"
                                                       disabled="disabled"/> <?php esc_html_e("Generate an illustration", "skyposter") ?>
                    </label>
                    <label>
                        <div><?php esc_html_e("Add to", "skyposter") ?></div>
                        <select skyposter_poststatus>
                            <option value="draft"><?php esc_html_e("Drafts", "skyposter") ?></option>
                            <option value="publish"><?php esc_html_e("Publish", "skyposter") ?></option>
                        </select>
                    </label>

                    <!-- List of categories-->
                    <label>
                        <div><?php esc_html_e("Category", "skyposter") ?></div>
                       <?php wp_dropdown_categories(array(
                          //'show_option_none' => esc_html_e( 'select category' ),
                          'orderby' => 'name',
                          'echo' => 1,
                          'selected' => 0,
                          'hierarchical' => 1,
                          'name' => 'skyposter_category', // field attribute "name"
                          'id' => '',
                          'class' => 'postform', // CSS class
                          'depth' => 7,
                          'tab_index' => 0,
                          'taxonomy' => 'category',
                          'hide_if_empty' => 0,
                          'hide_empty' => 0
                       )); ?>
                    </label>

                    <!-- List of authors-->
                    <label>
                        <div><?php esc_html_e("Author of the posts", "skyposter") ?>:</div>
                       <?php wp_dropdown_users(array(
                          //'show_option_none' => esc_html_e( '' ),
                          'echo' => 1,
                          'name' => 'skyposter_author', // Field name
                          'class' => 'postform', // CSS class
                          'selected' => get_query_var('author'), // Default author
                       )); ?>
                    </label>

                    <!-- LANGUAGE-->
                    <label>
                        <div><?php esc_html_e("Language of posts", "skyposter") ?></div>
                        <input style="width: 200px" type="text" value="<?php echo esc_html($language_name) ?>" id="mm_post_language"/>
                    </label>
                </div>


                <div class="structure">
                    <div><?php esc_html_e("Describe the structure of the article, one section in each line", "skyposter") ?></div>
                    <textarea rows="11" id="ArticleStructureText" style="width: 100%"
                              placeholder="<?php esc_html_e("To automatically create article sections, leave this field blank\n\nOR for articles about cats:\n1. Origin\n2. Character\n3. Behavior\n4. Health\n5. Nutrition\n6. Care", "skyposter") ?>"></textarea>
                </div>
            </div>
        </div>

        <!-- TEXT STYLE AND TEST -->
        <br>
        <div class="section">
            <h2>
                <div class style="display:flex;align-items: center;">
                    <div class="number"
                         style="width: 28px;height: 28px;font-size: 20px;line-height: initial;text-align: center;border: 1px solid #000;border-radius: 50%;line-height: 1.4;margin-right: 10px;">
                        3
                    </div>
                    <h2><?php esc_html_e("Style of text and Test", "skyposter") ?></h2></div>
            </h2>
            <div style="margin-bottom: 15px"><?php esc_html_e("Here you can test the result on the first keyword phrase that you get for all pages. And set the text style and other text parameters, if you need", "skyposter") ?></div>
            <div class="">
                <label>
                <textarea rows="3" style="width: 70%; margin-bottom: 5px" id="refineStyle"
                       placeholder="<?php esc_html_e("Style, formatting, size. Optional", "skyposter") ?>"></textarea>
                </label>
            </div>


            <h3><?php esc_html_e("Example of a post","skyposter") ?></h3>
            <div style="margin-top: 5px; margin-bottom: 15px">
                <span style="margin-right: 15px;"><strong><?php esc_html_e("Keyword", "skyposter") ?>: </strong><span
                            id="skyposter_Check_Keyword"></span></span>
                <span style="margin-right: 15px;"><strong><?php esc_html_e("Prompt", "skyposter") ?>: </strong><span
                            id="skyposter_Check_Prompt"></span></span>
                <span style="margin-right: 15px;"><strong><?php esc_html_e("Title tag", "skyposter") ?>: </strong><span
                            id="skyposter_Check_Title"></span></span>
                <span style="margin-right: 15px;"><strong><?php esc_html_e("H1 (article title)", "skyposter") ?>: </strong><span
                            id="skyposter_Check_H1"></span></span>
                <span style="margin-right: 15px;"><strong><?php esc_html_e("Meta tag Description", "skyposter") ?>: </strong><span
                            id="skyposter_Check_metadesc"></span></span>
            </div>

            <button onclick="checkStyle()"
                    class="button button-large"><?php esc_html_e("Generate example page", "skyposter") ?></button>
            <div id="PromptTestError"></div>
            <div id="PromptTestResult" style="width: 100%"></div>
        </div>

        <br>

        <div class="section">
            <h2>
                <div class style="display:flex;align-items: center;">
                    <div class="number"
                         style="width: 28px;height: 28px;font-size: 20px;line-height: initial;text-align: center;border: 1px solid #000;border-radius: 50%;line-height: 1.4;margin-right: 10px;">
                        4
                    </div>
                    <h2><?php esc_html_e("Create articles", "skyposter") ?></h2></div>
            </h2>
            <div>
                <div><?php echo __('Schedule articles release', 'skyposter') ?>: </div>
                <form style="margin: 6px 0; margin-bottom: 20px">
                    <label style="display: inline-block; margin-right: 10px;">
                        <input type="radio" name="skyposter_frequency_radio" value="none" checked> <?php echo __('No', 'skyposter') ?>
                    </label>
                    <label style="display: inline-block; margin-right: 10px;">
                        <input type="radio" name="skyposter_frequency_radio" value="86400">  <?php echo __('Once a day', 'skyposter') ?>
                    </label>
                    <label style="display: inline-block; margin-right: 10px;">
                        <input type="radio" name="skyposter_frequency_radio" value="43200">  <?php echo __('Twice a day', 'skyposter') ?>
                    </label>
                    <label style="display: inline-block; margin-right: 10px;">
                        <input type="radio" name="skyposter_frequency_radio" value="17280">  <?php echo __('Five times a day', 'skyposter') ?>
                    </label>
                </form>
            </div>
            <p id="totalArticlesMessage"></p>
            <button onclick="generateArticles()" class="button-primary"
                    id="GenerateButton"><?php esc_html_e("Generate", "skyposter") ?></button>
            <div id="generatedArticlesContainer"></div>
        </div>
    </div>

    <!-- SETTINGS -->
    <div id="Settings" class="tabcontent" style="display: none">

       <?php include('settings.php') ?>

    </div>
</div>

<style>
    .wp-style-flex-container {
        display: flex;
        flex-direction: column;
        justify-content: flex-start;
        align-items: stretch;
    }

    .flex-container {
        display: flex;
        justify-content: space-between;
    }

    .section {
        margin-bottom: 1em;
    }
    .section h2 {
        margin: 14px 0;
    }

    .tabcontent {
        display: none;
    }

    .tablinks {
        padding: 1em;

    }

    .tab .tablinks.active {
        background-color: #ddd;
    }

    .header1 {
        display: flex;
        background: #fff;
    }

    #loadFile {
        opacity: 0;
        width: 0.1px;
        height: 0.1px;
        position: absolute;
    }

    .keywords_block label {
        display: block;
        position: relative;
        display: flex;
        align-items: center;
        justify-content: center;
        color: #fff;
        cursor: pointer;
        transition: transform .2s ease-out;
    }

    input:hover + label,
    input:focus + label {
        transform: scale(1.02);
    }

    /* Adding an outline to the label on focus */
    input:focus + label {
        outline: 1px solid #000;
        outline: -webkit-focus-ring-color auto 2px;
    }

    select {
        width: 200px;
        margin-bottom: 15px
    }

    #skyposter_placeholderDiv {
        position: absolute;
        top: 0;
        padding: 6px 13px;
        color: #a5a5a5;
        display: none;
    }

    #skyposter_keylist_wrap {
        position: relative;
        background-color: white;
    }

    .wp-style-flex-container{width:80%}
    .settings{display:flex;}

    .theme{gap: 2%;}

    @media screen and (min-width: 600px) {
        .keywords_block{width:35%}
    }



    @media screen and (max-width: 600px) {
        .wp-style-flex-container{width:97%}
        .flex-container.theme{flex-direction: column;}
        .settings{flex-direction: column;}
        .wp-core-ui select, input{width: 100% !important}
        .structure{margin-top: 20px;}
    }

</style>
