/**
 * FRONTEND
 */

// Load localization globally

/**
 * Direct function without localization if it is not supported
 * @param text
 * @private
 */
let __ = (text) => text;
let _x = (text, params) => text;

/**
 * Load localization from Wordpress
 */
if (typeof wp !== 'undefined' && typeof wp.i18n !== 'undefined') {

    // Fill text domain automatically via native functions
    __ = (text) => wp.i18n.__(text, "skyposter");
    _x = (text, params) => wp.i18n._x(text, params, "skyposter");

}


/**
 * Change pages on settings page
 * @param evt
 * @param tabName
 */
function skyposter_changeTab(evt, tabName) {

    const tabcontent = document.getElementsByClassName("tabcontent");
    for (let i = 0; i < tabcontent.length; i++) {
        tabcontent[i].style.display = "none";
    }

    const tablinks = document.getElementsByClassName("tablinks");
    for (let i = 0; i < tablinks.length; i++) {
        tablinks[i].className = tablinks[i].className.replace(" active", "");
    }

    document.getElementById(tabName).style.display = "block";
    evt.currentTarget.className += " active";

    // update link on browser
    updateQueryParam("mm", tabName)

}

/**
 * Updates or adds a parameter to the current URL.
 * @param {string} key - The parameter key
 * @param {string} value - The parameter value
 */
function updateQueryParam(key, value) {
    // Get the current URL
    const url = new URL(window.location.href);

    // Get the parameters from the current URL
    const params = new URLSearchParams(url.search);

    // Set or add the parameter
    params.set(key, value);

    // Update the search part of the URL
    url.search = params.toString();

    // Update the address bar without reloading the page
    window.history.pushState({}, '', url.toString());
}


/**
 * File upload
 * Get the file, check for CSV format and parse it into field
 */
document.getElementById('loadFile').addEventListener('change', function (e) {

    const file = e.target.files[0];
    if (!file) return;

    // Check for CSV format
    if (file.type !== 'text/csv') return alert(__("Only CSV files are accepted. Google Keyword Planner and Yandex Wordstat formats are also suitable"));

    const reader = new FileReader();
    reader.readAsText(file, 'UTF-8');

    reader.onload = function (event) {
        const csv = event.target.result;
        const lines = csv.split(/(\r|\n)/).filter(r => r.trim().length !== 0);

        let splitter = ";", startLine = 1;

        let needAllFields = true;

        // Detect CSV formats

        // GOOGLE KEYWORD PLANNER
        if (lines[0].startsWith('Keyword Stats') && lines[2].startsWith("Keyword\tCurrency")) {
            splitter = "\t";
            startLine = 3;
            needAllFields = false;
        }
        // YANDEX WORDSTAT
        else if (lines[0].startsWith('Формулировка;Число запросов;')) {
            splitter = ";";
            startLine = 1;
            needAllFields = false;
        }
        // ANY CSV WITH ; SEPARATOR
        else if (lines[0].indexOf(';') !== -1) {
            splitter = ";";
        }
        // ANY CSV WITH , SEPARATOR
        else if (lines[0].indexOf(',') !== -1) {
            splitter = ",";
        }

        // parse keywords via detected formats
        const firstColumnValues = lines.map((line, index) => {
            if (index < startLine) return null;
            const columns = line.split(splitter);
            if (columns[0].trim().length === 0) return null;
            if(needAllFields)
                return columns.join(";");
            else
                return columns[0].replace(/(\+)/g,"").trim();
        }).filter((r) => r !== null);

        // set field
        document.getElementById('skyposter_keyWords').value = firstColumnValues.join("\n");

        // keylist update
        skyposter_parse_Keylist();

    }

    reader.onerror = function (event) {
        alert(__('File read error'));
    }
});

// Key List update
document.getElementById('skyposter_keyWords').addEventListener('blur', function (e) {

    skyposter_parse_Keylist();

})


// Scheduled posting checkbox
function changeScheduledPostingChk() {

    let chk = document.getElementById('scheduledPostingEnabled');
    document.getElementById('interval_minutes').disabled = !chk.checked;
    document.getElementById('interval_hours').disabled = !chk.checked;
    document.getElementById('interval_days').disabled = !chk.checked;
}

// changeScheduledPostingChk();

/**
 * Set first tab after page load
 */
window.addEventListener('DOMContentLoaded', () => {

    // activate first tab
    const url = new URL(window.location.href);
    let tabName = url.searchParams.get("mm");

    if (tabName === null) tabName = 'generator';

    switch (tabName.toLowerCase()) {
        case 'generator':
            document.getElementById('TM_TabGenerator').click();
            return;
        case 'settings':
            document.getElementById('TM_TabSettings').click();
            return;
    }

});


function setArticleStructure(id) {

    let el = document.getElementById('ArticleStructureText');

    switch (id) {
        case 0:
            el.value = "Подборка";
            break;
        case 1:
            el.value = `1.
            `
    }

}
