/**
 * CORE FUNCTIONS
 */

let skyposter_NONCE = "";

/**
 * Request to backend
 * @param data
 * @param success_el DOM Element for write the result
 * @param error_el DOM Element for write the error
 * @returns {Promise<any>}
 */
function skyposter_request(data, success_el = null, error_el = null) {

    // Json data of request
    let dataFSend = {
        endpoint: 'site/task',
        data: data,
        nonce: skyposter_NONCE,
    };


    // Post a request and write result or error, if any
    return fetch(ajaxurl + '?action=skyposter_ajax_action_request', {
        method: 'POST',
        credentials: 'same-origin',
        headers: new Headers({
            'Content-Type': 'application/json; charset=UTF-8',
        }),
        body: JSON.stringify(dataFSend)
    })
        .then(response => response.json())
        .then(dataResponse => {

            // set new nonce, if needed
            if (typeof dataResponse.data.nonce === 'string')
                skyposter_NONCE = dataResponse.data.nonce;

            // errors via catch handler
            if (dataResponse.data.status === 'error') throw dataResponse.data.message;

            // Success: set result as element text, if needed
            if (success_el !== null && typeof dataResponse.data.message !== 'undefined')
                document.querySelector(success_el).innerText = dataResponse.data.message;

            // Error field set to empty
            if (error_el !== null)
                document.querySelector(error_el).innerText = "";

            return dataResponse;
        })
        .catch((error) => {

            // Any error: from backend or browser - write error message to the specified DOM Element
            if (error_el !== null && typeof error !== 'undefined')
                document.querySelector(error_el).innerText = error;

            // Success DOM Element set to empty
            if (success_el !== null)
                document.querySelector(success_el).innerText = '';

            // Console log for technical support
            console.error('Error:', error)

            // Bubble the error
            throw error;

        });


}

// REQUESTS

/**
 * Generate list of keywords
 */
function generateKeyword() {

    // Combine JSON-request

    let keyList = document.getElementById('skyposter_keyWords').value;
    let subPromt = document.getElementById('newKeyword').value;
    let lang = document.getElementById('mm_post_language').value;
    const totalArticles = parseInt(document.getElementById('totalArticles').value);
    let dataFSend = {
        type: 'KEYWORDSGEN',
        keylist: keyList,
        subpromt: subPromt,
        count: totalArticles,
        lang: lang
    };

    // Set the spinner from default wordpress gif
    document.getElementById('KeywordsError').innerHTML = "<img src='./images/wpspin_light-2x.gif' />";

    // Do the request
    skyposter_request(dataFSend, null, '#KeywordsError')
        .then(data => {
            // Set keywords to a field
            document.getElementById('skyposter_keyWords').value = data.data.choices[0];
        })
}


/**
 * Test Article result without posting
 * This is async request
 */
function checkStyle() {

    // Combine JSON-request
    let KeysSplitted = skyposter_parse_Keylist();
    let subPromt = document.getElementById('refineStyle').value;
    let model = document.querySelector('[skyposter_models]').value;
    let skyposter_structure = document.getElementById('ArticleStructureText').value;
    let lang = document.getElementById('mm_post_language').value;

    if (KeysSplitted.length === 0) {
        alert(__("Write one or more keyword to generate"));
        return;
    }

    let dataFSend = {
        type: 'PROMPTTEST',
        keyword: KeysSplitted[0],
        keywords: KeysSplitted,
        subpromt: subPromt,
        model: model,
        struct: skyposter_structure,
        withPost: false,
        lang: lang
    };

    // Spinner
    document.getElementById('PromptTestResult').innerHTML = "<img src='./images/wpspin_light-2x.gif' />";

    // Create the task
    skyposter_request(dataFSend, null, '#PromptTestError')
        .then(r => {

            // Running periodic checks to see if the task is completed
            return skyposter_check_task(r.data.task)

        })
        .then(data => {

            // SUCCESS. Task completed: set text to DOM Element
            document.getElementById('PromptTestResult').innerHTML = '<h1>' + data.data.tasks[0].answer.choices[0].title + "</h1>" + data.data.tasks[0].answer.choices[0].text;

        })
        .catch((error) => {

            // ERROR

            // The error message was automatically set in bubble

            // Set the result as empty
            document.getElementById('PromptTestResult').innerText = "";

        });
}

/**
 * Generate article with posting
 * This is async request
 * @returns {Promise<void>}
 */
async function generateArticles() {

    // Combine JSON-request

    const totalArticles = parseInt(document.getElementById('totalArticles').value);

    let KeysSplitted = skyposter_parse_Keylist();
    let subPromt = document.getElementById('refineStyle').value;
    let model = document.querySelector('[skyposter_models]').value;
    let poststatus = document.querySelector('[skyposter_poststatus]').value;
    let skyposter_category = document.querySelector('[name="skyposter_category"]').value;
    let skyposter_author = document.querySelector('[name="skyposter_author"]').value;
    let skyposter_structure = document.getElementById('ArticleStructureText').value;
    let lang = document.getElementById('mm_post_language').value;
    const selectedRadio = document.querySelector('input[name="skyposter_frequency_radio"]:checked');

    if (KeysSplitted.length === 0) {
        alert(__("Write one or more keyword to generate"));
        return;
    }

    let dataFSend = {
        type: 'ARTICLE',
        keyword: KeysSplitted[0], // compatibility with old api
        keywords: KeysSplitted,
        subpromt: subPromt,
        model: model,
        struct: skyposter_structure,
        post_status: poststatus,
        post_category: skyposter_category,
        post_author: skyposter_author,
        post_frequency: selectedRadio.value,
        post_timestamp: null,
        lang: lang,
        withPost: true
    };

    // Dates of posting
    let startDate = new Date();
    let secondsToAdd = 0;
    if(selectedRadio.value !== null) secondsToAdd=parseInt(selectedRadio.value);


    // Spinner and information
    document.getElementById('totalArticlesMessage').textContent = __(`A total of `) + totalArticles + __(` articles will be created`);
    document.getElementById('generatedArticlesContainer').innerHTML = "<img id='tm_spinner' src='./images/wpspin_light-2x.gif' />";


    // Start task for each keyword
    for (let i = 0; i < KeysSplitted.length; i++) {

        document.getElementById('totalArticlesMessage').textContent = `Создаётся ${(i + 1)} из ${KeysSplitted.length} статей`

        dataFSend.keyword = KeysSplitted[i];

        let result = await skyposter_request(dataFSend, null, '#PromptTestError')
            .then(r => {

                // Running periodic checks to see if the task is completed
                return skyposter_check_task(r.data.task)

            })
            .then(data => {

                // Добавляем пункт
                for (let j = 0; j < data.data.tasks.length; j++) {

                    const div = document.createElement('div');
                    div.innerHTML = __("The article ") + (i + 1) + __(" is generated") + `: <a href=${data.data.tasks[j].post_link} target="_blank">${data.data.tasks[j].post_name}</a> | <a target="_blank" href="${data.data.tasks[j].post_link_edit}">` + __('Edit') + "</a>" + (data.data.tasks[j].post_date === null ? '' : ' | ' + __('Will be published on: ') + (data.data.tasks[j].post_date) + " GMT");
                    div.style.color = 'green';

                    document.getElementById('generatedArticlesContainer').prepend(div);
                }
            })
            .catch((error) => {
                document.getElementById('PromptTestError').innerText = error;
                document.getElementById('PromptTestResult').innerText = "";
                console.error('Error:', error)
            });

        if(secondsToAdd !== 0) {
            let newDate = new Date(startDate.getTime() + secondsToAdd * 1000);
            dataFSend.post_timestamp = Math.floor(newDate.getTime() / 1000);
            startDate = newDate;
        }


    }

    document.getElementById('tm_spinner').remove();

}

function skyposter_parse_Keylist() {

    let keyList = document.getElementById('skyposter_keyWords').value;
    if (keyList.trim().length === 0) return [];

    let KeysSplitted = keyList.split(/[\n]/).map(item => item.trim());

    const result = KeysSplitted.map(res => {
        // keyword; prompt; title; h1; meta description
        let r = res.split(";");
        return {
            keyword: r[0].trim(),
            prompt: r.length > 1 && r[1].length > 0 ? r[1].trim() : null,
            title: r.length > 2 && r[2].length > 0 ? r[2].trim() : null,
            h1: r.length > 3 && r[3].length > 0 ? r[3].trim() : null,
            meta_desc: r.length > 4 && r[4].length > 0 ? r[4].trim() : null,
        };
    });

    // Set first keyword for example and testing
    document.getElementById('skyposter_Check_Keyword').innerText = result[0].keyword;
    // ECMA1
    document.getElementById('skyposter_Check_Prompt').innerText = result[0].prompt === null ? "auto" : result[0].prompt;
    document.getElementById('skyposter_Check_Title').innerText = result[0].title === null ? "auto" : result[0].title;
    document.getElementById('skyposter_Check_H1').innerText = result[0].h1 === null ? "auto" : result[0].h1;
    document.getElementById('skyposter_Check_metadesc').innerText = result[0].meta_desc === null ? "auto" : result[0].meta_desc;

    return result;

}

function skyposter_check_task(taskID) {
    return new Promise((resolve, reject) => {
        const intervalObj = setInterval(async () => {
            try {
                let result = await skyposter_getINFO(taskID);
                if (result.data.tasks[0].status === 'COMPLETED') {
                    clearInterval(intervalObj);
                    resolve(result);
                }
                if (result.data.tasks[0].status === 'ERROR') {
                    clearInterval(intervalObj);
                    reject(result);
                }
            } catch (ex) {
                reject(ex);
            }
        }, 5000);
    });
}

///////////////////////////////////////////


function skyposter_getINFO(taskID = 0) {

    let dataFSend = {
        type: 'INFO',
    };

    if (taskID !== 0) dataFSend['taskID'] = taskID;

    return skyposter_request(dataFSend, null, '[skyposter_bananas]')
        .then(data => {
            document.querySelector('[skyposter_bananas]').innerHTML = data.data.coins;
            skyposter_NONCE = data.data.nonce;
            return data;
            //document.querySelector('[skyposter_bananas]').innerHTML = data.data.coins;
        })
}

// Get info after run
skyposter_interval_info = null;
skyposter_getINFO().then(r => {

    // periodically get nonce and updates
    skyposter_interval_info = setInterval(() => skyposter_getINFO(), 60000)

}).catch(ex => {

    // finally is not supported in Chrome versions below 63.
    skyposter_interval_info = setInterval(() => skyposter_getINFO(), 60000)

});
